# natari

[![License](https://img.shields.io/pypi/l/natari.svg?color=green)](https://github.com/haesleinhuepf/natari/raw/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/natari.svg?color=green)](https://pypi.org/project/natari)
[![Python Version](https://img.shields.io/pypi/pyversions/natari.svg?color=green)](https://python.org)

Napari gaming

## Cell counting arcade
Commander! Cells are intruding our dish! Control your tiny space ship using `1` and `2` keys to move it left/right.
Use the `9` key to shoot a anti-cell bullet.

![](https://github.com/haesleinhuepf/natari/raw/master/images/cell_counting_arcade.gif)

The image originates from [BBBC022v1](https://bbbc.broadinstitute.org/BBBC022) (Gustafsdottir et al., PLOS ONE, 2013), available from the Broad Bioimage Benchmark Collection (Ljosa et al., Nature Methods, 2012).

## Snake
Two mitochondria navigating in a cell searching for stress granules. 
The two players can control their mito using the `W`, `A`, `S`, `D` and `I`, `J`, `K`, `L`  keys, respectively.

![](https://github.com/haesleinhuepf/natari/raw/master/images/snake.gif)

## Ping pong
Don't drop the organoid! Use your racket and hit it back to your colleague!
The two players can use `W`, `S` and `I`, `K` to control their racket, respectively.

![](https://github.com/haesleinhuepf/natari/raw/master/images/ping_pong.gif)


This [napari] plugin was generated with [Cookiecutter] using with [@napari]'s [cookiecutter-napari-plugin] template.

## Installation

You can install `natari` via [pip]:

    pip install natari

## Known issues

* To make the keyboard buttons work, you sometimes have to click within the image after starting the game.

## Contributing

Contributions are very welcome. 

## License

"natari" is free and open source software. The code is in the public domain.

[See also: unlicense.org](https://unlicense.org)

## Issues

If you encounter any problems, please [file an issue] along with a detailed description.

[napari]: https://github.com/napari/napari
[Cookiecutter]: https://github.com/audreyr/cookiecutter
[@napari]: https://github.com/napari
[MIT]: http://opensource.org/licenses/MIT
[BSD-3]: http://opensource.org/licenses/BSD-3-Clause
[GNU GPL v3.0]: http://www.gnu.org/licenses/gpl-3.0.txt
[GNU LGPL v3.0]: http://www.gnu.org/licenses/lgpl-3.0.txt
[Apache Software License 2.0]: http://www.apache.org/licenses/LICENSE-2.0
[Mozilla Public License 2.0]: https://www.mozilla.org/media/MPL/2.0/index.txt
[cookiecutter-napari-plugin]: https://github.com/napari/cookiecutter-napari-plugin

[file an issue]: https://github.com/haesleinhuepf/natari/issues

[napari]: https://github.com/napari/napari
[tox]: https://tox.readthedocs.io/en/latest/
[pip]: https://pypi.org/project/pip/
[PyPI]: https://pypi.org/
